@@ -9,29 +9,24 @@
  *		 IBM Corporation - initial API and implementation
  *******************************************************************************/
 /*eslint-env node */
-var api = require('../api'), writeError = api.writeError;
-var git = require('nodegit');
 var clone = require('./clone');
-var path = require('path');
 var express = require('express');
-var util = require('./util');
 var request = require('request');
-var https = require('https');
 var bodyParser = require('body-parser');
 var url = require("url");
-var fs = require('fs');
 var tasks = require('../tasks');
 
 module.exports = {};
 
 module.exports.router = function(options) {
 	var fileRoot = options.fileRoot;
-	if (!fileRoot) { throw new Error('options.root is required'); }
-	var contextPath = options.options.configParams["orion.context.path"] || "";
-
+	var gitRoot = options.gitRoot;
+	if (!fileRoot) { throw new Error('options.fileRoot is required'); }
+	if (!gitRoot) { throw new Error('options.gitRoot is required'); }
+	
 	return express.Router()
 	.use(bodyParser.json())
-	.post(contextPath + '/file*', getPullRequest);
+	.post(fileRoot + '*', getPullRequest);
 	
 function pullRequestJSON(cloneDir,remoteDir,bodyJson) {
 	var children = [];
@@ -76,7 +71,7 @@ function getPullRequest(req, res) {
 		var projectname = pathnames[2].replace(/\.git$/g, "");
 		var pullrequestUrl = "https://api.github.com/repos/" + username +"/" + projectname + "/pulls";
 		if(clientID && clientSecret){
-			pullrequestUrl += "?client_id="+clientID+"&client_secret="+clientSecret+"";
+			pullrequestUrl += "?client_id="+clientID+"&client_secret="+clientSecret;
 		}
 	}
 	var userAgentHeader = {
@@ -88,8 +83,8 @@ function getPullRequest(req, res) {
 	clone.getRepo(req)
 	.then(function(repo) {
 		fileDir = clone.getfileDir(repo,req); 
-		cloneDir = contextPath + "/gitapi/clone" + fileDir;
-		remoteDir = contextPath + "/gitapi/remote" + fileDir;
+		cloneDir = gitRoot + "/clone" + fileDir;
+		remoteDir = gitRoot + "/remote" + fileDir;
 		return request(userAgentHeader, function (error, response, body) {
 				if (!error && response.statusCode === 200) {
 					bodyJson = JSON.parse(body);
