@@ -9,7 +9,7 @@
  *     IBM Corporation - initial API and implementation
  *******************************************************************************/
 /*eslint-env node */
-var api = require('../api'), writeError = api.writeError;
+var api = require('../api'), writeError = api.writeError, writeResponse = api.writeResponse;
 var git = require('nodegit');
 var mCommit = require('./commit');
 var clone = require('./clone');
@@ -20,15 +20,16 @@ module.exports = {};
 
 module.exports.router = function(options) {
 	var fileRoot = options.fileRoot;
-	if (!fileRoot) { throw new Error('options.root is required'); }
-	var contextPath = options.options.configParams["orion.context.path"] || "";
+	var gitRoot = options.gitRoot;
+	if (!fileRoot) { throw new Error('options.fileRoot is required'); }
+	if (!gitRoot) { throw new Error('options.gitRoot is required'); }
 	
 	return express.Router()
 	.use(bodyParser.json())
 	.get('*', getStash)
-	.delete(contextPath + '/file*', deleteStash)
+	.delete(fileRoot + '*', deleteStash)
 	.delete('/:stashRev*', deleteStash)
-	.put(contextPath + '/file*', putStash)
+	.put(fileRoot + '*', putStash)
 	.put('/:stashRev*', putStash)
 	.post('*', postStash);
 
@@ -53,8 +54,8 @@ function getStash(req, res) {
 				var diffs = commitAndDiffs[1];
 				var parents = commitAndDiffs[2];
 				var stashCommit = mCommit.commitJSON(commit, fileDir, diffs, parents);
-				stashCommit["ApplyLocation"] = contextPath + "/gitapi/stash/" + oid + fileDir;
-				stashCommit["DropLocation"] = contextPath + "/gitapi/stash/" + oid + fileDir;
+				stashCommit["ApplyLocation"] = gitRoot + "/stash/" + oid + fileDir;
+				stashCommit["DropLocation"] = gitRoot + "/stash/" + oid + fileDir;
 				stashCommit["Type"] = "StashCommit";
 				return stashCommit;
 			}));
@@ -64,12 +65,12 @@ function getStash(req, res) {
 		return Promise.all(stashesPromises);
 	})
 	.then(function(stashes) {
-		res.status(200).json({
+		writeResponse(200, res, null, {
 			"Children" : stashes,
-			"Location" : contextPath + "/gitapi/stash" + fileDir,
-			"CloneLocation" : contextPath + "/gitapi/clone" + fileDir,
+			"Location" : gitRoot + "/stash" + fileDir,
+			"CloneLocation" : gitRoot + "/clone" + fileDir,
 			"Type" : "StashCommit"
-		});
+		}, true);
 	})
 	.catch(function(err) {
 		writeError(500, res, err.message);
