@@ -10,10 +10,11 @@
  *******************************************************************************/
 /*eslint-env node */
 var express = require('express');
+var api = require('./api');
 
 module.exports = {};
 
-var BUILD_ID = "2017-05-01_11-31-32";
+var BUILD_ID = "2017-05-02_19-51-33";
 
 module.exports.router = function(options) {
 	var configParams = options.configParams;
@@ -22,8 +23,7 @@ module.exports.router = function(options) {
 	return express.Router()
 	.get('*', /* @callback */ function (req, res) {
 		var buildID = configParams["orion.buildId"] || BUILD_ID;
-		res.setHeader("Cache-Control", "no-cache");
-		return res.status(200).json({
+		return api.writeResponse(200, res, null, {
 			build: buildID
 		});
 	});
